%% this is the main function that computes the spectral gap from the
%% impulse response.
%%
%% A : transition matrix
%%
%% k : minimum length of the impulse response to use rounded up to the
%% nearest odd number
%%
%% G : vector containing the estimates of the spectral gap for each
%% vertex
%%
function K = impulse_gap_error2(A,x,max_k=201)
  
  printf("Computing the gap estrimation with a long impulse response\n");  
  n = size(A)(1);
  A = make_col_stochastic(A);
  b = init_b_nonzero(n);
  H = impulse_response(A,b,max_k);
  Gmax = [];
  for i = 1:n
    Gmax = [ Gmax ; gap_estimate_nonzero_b(H(i,:)) ];
  endfor
  
  K = [];

  TOL = [ 1e-1 1e-2 1e-3 1e-4 1e-5 1e-6 ];

  errors = ones(1,5);
  e_i = 1;

  k = floor(x/2)*2+1;
  for T = TOL
    printf("T=%f\n", T);
    while(any(errors > T))
      G = [];
      for i = 1:n
	G = [ G ; gap_estimate_nonzero_b(H(i,1:k)) ];
      endfor
      k = k + 2;
      errors(e_i) = max(abs(G - Gmax));
      printf("k = %d, max error = %f\n", k, errors(e_i));
      e_i = e_i + 1;
      if e_i > 5
	e_i = 1;
      endif
    endwhile
    K = [K k];
  endfor
