# -*- octave -*-
#

## Computes the impulse response of a system A with initial state x1
## (=B), from time 1 to k1, then at k1 eliminates node v, and proceeds
## further to time k2.  The failure is "undetected" so th nodes t
## that had outgoing edges towards node v still send messages to it 
##
## A: state-transition matrix
##
## x1: initial state vector
##
## k1: length of the first phase of the impulse response
##
## k2: length of the second phase of the impulse response
##
## v: node killed at time k1
##
function Y = impulse_response_with_undetected_failure(A, x1, k1, k2, v=1)
  n = size(A)(1);
  ##
  ## we first compute k1 steps of the impulse response.
  ##
  ##A
  Y = [ x1 ];
  k1 = floor(k1/2);
  for i = 1:k1
    x1 = A*x1;
    Y = [ Y x1 ];
    x1 = A*x1;
    Y = [ Y x1 ];
  endfor
  ##
  ## it's now time to "kill" node v. We simply set to zero the coloum v 
  ## of the matrix 
  ##
  
  ## to do: detect dead end nodes...
  
  A(:,v) = zeros(n,1);
  ## as a paranoia precaution, we also zero out v's state in x
  x1(v) = 0;
  ## and now we are ready restart with the impulse response
  ##A
  k2 = floor(k2/2);
  for i = 1:k2
    x1 = A*x1;
    Y = [ Y x1 ];
    x1 = A*x1;
    Y = [ Y x1 ];
  endfor
