%% -*- octave -*-
%%
%% performs an experiment to evaluate the precision of the
%% impulse-response method over multiple initial vectors (B).  The
%% parameters are as follows:
%%
%% A: adjacency matrix of the network
%%
%% k: length of the impulse response to be used
%%
%% m: number of initial vectors to try
%%
%% fname: base name of the files in which the results will be saved.  In
%% particular:
%%
%%   - fname.mat: adjacency matrix in Octave format
%%
%%   - fname.am: adjacency matrix in a format loadable by the "adjacency
%%     matrix" plugin of the Tulip graph visualization program.
%%
%%   - fname.am: adjacency matrix in a format loadable by the "adjacency
%%     matrix" plugin of the Tulip graph visualization program.
%%
%%   - fname.dat: a file to be processed by gnuplot in which the first
%%     row contains the actual spectral gap of the matrix A in a gnuplot
%%     comment (e.g., '# actual=0.433305') and every other row contains
%%     the minimum, 25th percentile, median, 75th percentile, and maximum
%%     estimation of the spectral gap of an individual node.  The rows are
%%     sorted in ascending order of the minimal estimate.  The first value
%%     in every row is simply a counter that can be through of as a node
%%     id.
%%
function E = init_vector_gossip_experiment(A, k=100, m=100, fname="A")
  save(strappend({fname},".mat"){1:1}, "A");
  g = gap(A);
  printf("actual gap = %f\n", g);
  printf("impulse_gap for various init vectors...\n");
  V = impulse_gap(A, k);
  for i = 1:m
    printf(".");
    V = [V impulse_gap(A, k)];
  endfor
  printf("\nquantiles...\n");
  Q = transpose(quantile(transpose(V), [0 0.25 0.5 0.75 1]));
  printf("saving graph...\n");
  V = Q(:,3);
  save_graph(strappend({fname},".am"){1:1}, A, V);
  printf("saving sorted results...\n");
  S = sort(Q);
  n = size(S)(1);
  E = [ transpose(linspace(1, n, n)) S ];
  fid = fopen(strappend({fname},".dat"){1:1}, "w");
  fprintf(fid, "# actual=%f\n", g);
  fdisp(fid, E);
  fclose(fid);
endfunction
